@@ -1,16 +1,17 @@
 package Proc::Govern;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-08-06'; # DATE
-our $DIST = 'Proc-Govern'; # DIST
-our $VERSION = '0.212'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
 use Log::ger;
 
 use Exporter qw(import);
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2023-11-16'; # DATE
+our $DIST = 'Proc-Govern'; # DIST
+our $VERSION = '0.213'; # VERSION
+
 our @EXPORT_OK = qw(govern_process);
 
 our %SPEC;
@@ -727,7 +728,7 @@ Proc::Govern - Run child process and govern its various aspects
 
 =head1 VERSION
 
-This document describes version 0.212 of Proc::Govern (from Perl distribution Proc-Govern), released on 2021-08-06.
+This document describes version 0.213 of Proc::Govern (from Perl distribution Proc-Govern), released on 2023-11-16.
 
 =head1 SYNOPSIS
 
@@ -1113,18 +1114,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Proc-Gover
 
 Source repository is at L<https://github.com/perlancar/perl-Proc-Govern>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Proc-Govern>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=head1 CAVEATS
-
-Not yet tested on Win32.
-
 =head1 SEE ALSO
 
 L<Forks::Super> (since 2009) extends the fork(), wait(), and waitpid() functions
@@ -1155,6 +1144,10 @@ djb's B<supervise>, http://cr.yp.to/daemontools/supervise.html
 
 =item * Pausing under high system load
 
+L<run-stop-run> from L<App::RunStopRun> employs the same technique of
+stopping/resuming processes periodically but does not seem to monitor system
+load or CPU usage.
+
 B<loadwatch>. This program also has the ability to run N copies of program and
 interactively control stopping/resuming via Unix socket.
 
@@ -1199,15 +1192,45 @@ perlancar <perlancar@cpan.org>
 
 =item *
 
-Steven Haryanto <sharyanto@cpan.org>
+Steven Haryanto <stevenharyanto@gmail.com>
 
 =back
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012 by perlancar.
+This software is copyright (c) 2023, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012 by perlancar.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Proc-Govern>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 CAVEATS
+
+Not yet tested on Win32.
+
 =cut
